@@ -32,12 +32,14 @@ namespace SparkleLib {
                 "sparkleshare");
 
         public static SparkleConfig DefaultConfig = new SparkleConfig (ConfigPath, "config.xml");
-
-
         public string FullPath;
 
-        public string HomePath = Environment.GetFolderPath (Environment.SpecialFolder.Personal);
-        public string TmpPath;
+        public string HomePath {
+            get {
+		        return Environment.GetFolderPath (Environment.SpecialFolder.Personal);
+		    }
+        }
+
 
         public string FoldersPath {
             get {
@@ -48,11 +50,16 @@ namespace SparkleLib {
             }
         }
 
+        public string TmpPath {
+            get {
+                return Path.Combine (FoldersPath, ".tmp");
+            }
+        }
+
 
         public SparkleConfig (string config_path, string config_file_name)
         {
             FullPath = System.IO.Path.Combine (config_path, config_file_name);
-            TmpPath  = Path.Combine (FoldersPath, ".tmp");
 
             if (!Directory.Exists (config_path)) {
                 Directory.CreateDirectory (config_path);
@@ -89,6 +96,8 @@ namespace SparkleLib {
             } finally {
                 Load (FullPath);
             }
+
+            ConfigureSSH ();
         }
 
 
@@ -151,6 +160,52 @@ namespace SparkleLib {
         }
 
 
+        private void ConfigureSSH ()
+        {
+            string path = Environment.GetFolderPath (Environment.SpecialFolder.Personal);
+
+            if (!(SparkleBackend.Platform == PlatformID.Unix ||
+                  SparkleBackend.Platform == PlatformID.MacOSX)) {
+
+                path = Environment.ExpandEnvironmentVariables ("%HOMEDRIVE%%HOMEPATH%");
+            }
+
+            string ssh_config_path      = Path.Combine (path, ".ssh");
+            string ssh_config_file_path = SparkleHelpers.CombineMore (path, ".ssh", "config");
+            string ssh_config           = "IdentityFile " +
+                Path.Combine (SparkleConfig.ConfigPath, "sparkleshare." + User.Email + ".key");
+
+            if (!Directory.Exists (ssh_config_path))
+                Directory.CreateDirectory (ssh_config_path);
+
+            if (File.Exists (ssh_config_file_path)) {
+                string current_config = File.ReadAllText (ssh_config_file_path);
+                if (current_config.Contains (ssh_config))
+                    return;
+
+                if (current_config.EndsWith ("\n\n"))
+                    ssh_config = "# SparkleShare's key\n" + ssh_config;
+                else if (current_config.EndsWith ("\n"))
+                    ssh_config = "\n# SparkleShare's key\n" + ssh_config;
+                else
+                    ssh_config = "\n\n# SparkleShare's key\n" + ssh_config;
+
+                TextWriter writer = File.AppendText (ssh_config_file_path);
+                writer.Write (ssh_config + "\n");
+                writer.Close ();
+
+            } else {
+                File.WriteAllText (ssh_config_file_path, ssh_config);
+            }
+
+            //UnixFileSystemInfo file_info = new UnixFileInfo (ssh_config_file_path);
+            //file_info.FileAccessPermissions = (FileAccessPermissions.UserRead |
+            //                                   FileAccessPermissions.UserWrite); TODO
+
+            SparkleHelpers.DebugInfo ("Config", "Added key to " + ssh_config_file_path);
+        }
+
+
         public List<string> Folders {
             get {
                 List<string> folders = new List<string> ();
