@@ -26,7 +26,7 @@ from gi.repository import Nautilus, GObject, Gtk, Gdk
 SPARKLESHARE_PATH = os.path.join (os.path.expanduser ('~'), "SparkleShare")
 
 import gettext
-gettext.bindtextdomain('sparkleshare', '/usr/local/share/locale')
+gettext.bindtextdomain('sparkleshare', '/usr/share/locale')
 gettext.textdomain('sparkleshare')
 _ = gettext.gettext
 
