@@ -35,7 +35,6 @@ namespace SparkleShare {
     public abstract class SparkleControllerBase {
 
         public List <SparkleRepoBase> Repositories;
-        public string FolderSize;
         public readonly string SparklePath = SparkleConfig.DefaultConfig.FoldersPath;
 
         public event OnQuitWhileSyncingHandler OnQuitWhileSyncing;
@@ -53,9 +52,6 @@ namespace SparkleShare {
         public event FolderListChangedHandler FolderListChanged;
         public delegate void FolderListChangedHandler ();
 
-        public event FolderSizeChangedHandler FolderSizeChanged;
-        public delegate void FolderSizeChangedHandler (string folder_size);
-        
         public event AvatarFetchedHandler AvatarFetched;
         public delegate void AvatarFetchedHandler ();
 
@@ -85,6 +81,8 @@ namespace SparkleShare {
         private SparkleFetcherBase fetcher;
         private List<string> failed_avatars = new List<string> ();
 
+        private Object avatar_lock = new Object ();
+
 
         // Short alias for the translations
         public static string _ (string s)
@@ -107,8 +105,6 @@ namespace SparkleShare {
             if (CreateSparkleShareFolder ())
                 AddToBookmarks ();
 
-            FolderSize = GetFolderSize ();
-
             if (FirstRun)
                 SparkleConfig.DefaultConfig.SetConfigOption ("notifications", bool.TrueString);
             else
@@ -128,11 +124,6 @@ namespace SparkleShare {
 
                 if (FolderListChanged != null)
                     FolderListChanged ();
-
-                FolderSize = GetFolderSize ();
-
-                if (FolderSizeChanged != null)
-                    FolderSizeChanged (FolderSize);
             };
 
 
@@ -161,8 +152,8 @@ namespace SparkleShare {
         public bool AcceptInvitation (string server, string folder, string token)
         {
             // The location of the user's public key for SparkleShare
-            string public_key_file_path = SparkleHelpers.CombineMore (SparkleConfig.DefaultConfig.HomePath, ".ssh",
-                "sparkleshare." + UserEmail + ".key.pub");
+            string public_key_file_path = SparkleHelpers.CombineMore (SparkleConfig.DefaultConfig.HomePath,
+                ".ssh", "sparkleshare." + UserEmail + ".key.pub");
 
             if (!File.Exists (public_key_file_path))
                 return false;
@@ -532,31 +523,34 @@ namespace SparkleShare {
         // Fires events for the current syncing state
         public void UpdateState ()
         {
+            bool has_syncing_repos  = false;
+            bool has_unsynced_repos = false;
+
             foreach (SparkleRepoBase repo in Repositories) {
                 if (repo.Status == SyncStatus.SyncDown ||
                     repo.Status == SyncStatus.SyncUp   ||
                     repo.IsBuffering) {
 
-                    if (OnSyncing != null)
-                        OnSyncing ();
-
-                    return;
+                    has_syncing_repos = true;
 
                 } else if (repo.HasUnsyncedChanges) {
-                    if (OnError != null)
-                        OnError ();
-
-                    return;
+                    has_unsynced_repos = true;
                 }
             }
 
-            if (OnIdle != null)
-                OnIdle ();
 
-            FolderSize = GetFolderSize ();
+            if (has_syncing_repos) {
+                if (OnSyncing != null)
+                    OnSyncing ();
 
-            if (FolderSizeChanged != null)
-                FolderSizeChanged (FolderSize);
+            } else if (has_unsynced_repos) {
+                if (OnError != null)
+                    OnError ();
+
+            } else {
+                if (OnIdle != null)
+                    OnIdle ();
+            }
         }
 
 
@@ -650,11 +644,6 @@ namespace SparkleShare {
 
             if (FolderListChanged != null)
                 FolderListChanged ();
-            
-            FolderSize = GetFolderSize ();
-
-            if (FolderSizeChanged != null)
-                FolderSizeChanged (FolderSize);
         }
 
 
@@ -686,51 +675,37 @@ namespace SparkleShare {
         }
 
 
-        private string GetFolderSize ()
+        public string GetSize (string folder_name)
         {
-            double folder_size = CalculateFolderSize (
-                new DirectoryInfo (SparkleConfig.DefaultConfig.FoldersPath));
+            double folder_size = 0;
+            /* TODO
+            foreach (SparkleRepoBase repo in
+                Repositories.GetRange (0, Repositories.Count)) {
 
-            return FormatFolderSize (folder_size);
+                folder_size += repo.Size + repo.HistorySize;
+            }
+             */
+            return FormatSize (folder_size);
         }
 
 
-        // Recursively gets a folder's size in bytes
-        private double CalculateFolderSize (DirectoryInfo parent)
+        public string GetHistorySize (string folder_name)
         {
-            if (!Directory.Exists (parent.ToString ()))
-                return 0;
+            double folder_size = 0;
+            /* TODO
+            foreach (SparkleRepoBase repo in
+                Repositories.GetRange (0, Repositories.Count)) {
 
-            double size = 0;
-
-            // Ignore the temporary 'rebase-apply' and '.tmp' directories. This prevents potential
-            // crashes when files are being queried whilst the files have already been deleted.
-            if (parent.Name.Equals ("rebase-apply") ||
-                parent.Name.Equals (".tmp"))
-                return 0;
-
-            try {
-                foreach (FileInfo file in parent.GetFiles()) {
-                    if (!file.Exists)
-                        return 0;
-
-                    size += file.Length;
-                }
-
-                foreach (DirectoryInfo directory in parent.GetDirectories())
-                    size += CalculateFolderSize (directory);
-
-            } catch (Exception) {
-                return 0;
+                folder_size += repo.Size + repo.HistorySize;
             }
-
-            return size;
+             */
+            return FormatSize (folder_size);
         }
 
 
         // Format a file size nicely with small caps.
         // Example: 1048576 becomes "1 ᴍʙ"
-        private string FormatFolderSize (double byte_count)
+        public string FormatSize (double byte_count)
         {
             if (byte_count >= 1099511627776)
                 return String.Format ("{0:##.##} ᴛʙ", Math.Round (byte_count / 1099511627776, 1));
@@ -912,7 +887,10 @@ namespace SparkleShare {
                     // if not empty
                     if (buffer.Length > 255) {
                         avatar_fetched = true;
-                        File.WriteAllBytes (avatar_file_path, buffer);
+
+                        lock (this.avatar_lock)
+                            File.WriteAllBytes (avatar_file_path, buffer);
+
                         SparkleHelpers.DebugInfo ("Controller", "Fetched gravatar for " + email);
                     }
 
@@ -1014,28 +992,24 @@ namespace SparkleShare {
 
                 try {
                     Directory.Move (tmp_folder, target_folder_path);
+
+                    SparkleConfig.DefaultConfig.AddFolder (target_folder_name, this.fetcher.RemoteUrl, backend);
+                    AddRepository (target_folder_path);
+
+                    if (FolderFetched != null)
+                        FolderFetched (warnings);
+
+                    if (FolderListChanged != null)
+                        FolderListChanged ();
+
+                    this.fetcher.Dispose ();
+
+                    if (Directory.Exists (tmp_path))
+                        Directory.Delete (tmp_path, true);
+
                 } catch (Exception e) {
                     SparkleHelpers.DebugInfo ("Controller", "Error moving folder: " + e.Message);
                 }
-
-                SparkleConfig.DefaultConfig.AddFolder (target_folder_name, this.fetcher.RemoteUrl, backend);
-                AddRepository (target_folder_path);
-
-                if (FolderFetched != null)
-                    FolderFetched (warnings);
-
-                FolderSize = GetFolderSize ();
-
-                if (FolderSizeChanged != null)
-                    FolderSizeChanged (FolderSize);
-
-                if (FolderListChanged != null)
-                    FolderListChanged ();
-
-                this.fetcher.Dispose ();
-
-                if (Directory.Exists (tmp_path))
-                    Directory.Delete (tmp_path, true);
             };
 
 
